## SHAPES RECOGNITION
**shapes recognition** is a New Recognition Technology

### Installation
```
pip install shapes-recognition
```
### About "shapes-recognition"
Recognition is an intrinsic property of the human intellect. Kids around two years old recognize shapes even if they differ in size and position or are severely deformed. 

<p align="center"><img src="https://boriskravtsov.com/pypi/shapes.png"/>

To simulate such recognition capability, we introduce the **shapes-recognition** library.

[Here](https://kravtsov-development.medium.com/amazing-ai-tables-44af52c993a2) 
we show how to use it. 
